//This version is for use with RGB Neopixels

#include "Adafruit_FreeTouch.h"
#include <Adafruit_NeoPixel.h>
#ifdef __AVR__
#include <avr/power.h> // Required for 16 MHz Adafruit Trinket
#endif

#define PIN        1 //NEOPIXEL
#define NUMPIXELS 12 // Popular NeoPixel ring size
#define DELAYVAL 50 // Time (in milliseconds) to pause between pixels
Adafruit_NeoPixel pixels(NUMPIXELS, PIN, NEO_GRB + NEO_KHZ800);

int sound = 4;
Adafruit_FreeTouch qt_1 = Adafruit_FreeTouch(3  , OVERSAMPLE_4, RESISTOR_50K, FREQ_MODE_NONE); //CapSensePin
int button = 2;
int sense = 3;


int i = 0;
int v = 0;
int Value = 0;
int sensorMax = 0;
int sensorMin = 1023;
int red = 0;

int blu = 0;


void setup() {
  // put your setup code here, to run once:
  pinMode(button, INPUT);
  pinMode(sound, OUTPUT);
  pinMode(sense, INPUT);

#if defined(__AVR_ATtiny85__) && (F_CPU == 16000000)
  clock_prescale_set(clock_div_1);
#endif

  int buttonstate = digitalRead(button);

  qt_1.begin();

  Serial.begin(9600);
  pixels.begin(); // INITIALIZE NeoPixel strip object (REQUIRED)


  while (millis() < 5000) {

    if (buttonstate == HIGH) {
      Serial.println("Start in CAP Mode");
      theaterChase(pixels.Color(255, 10, 10), 100); // White, half brightness
      Value = qt_1.measure();
    }

    else {
      Serial.println("Start in RES Mode");
      theaterChase(pixels.Color(10, 10, 255), 100); // White, half brightness
      Value = analogRead(sense);

    }

    if (Value > sensorMax) {
      sensorMax = Value + 75;
    }

    if (Value < sensorMin) {
      sensorMin = Value - 75;
    }
  }

  Serial.print("sensorMin");
  Serial.println(sensorMin);
  Serial.print("sensorMax");
  Serial.println(sensorMax);

}

void loop() {
  // put your main code here, to run repeatedly:
  pixels.clear(); // Set all pixel colors to 'off'
  int buttonstate = digitalRead(button);

  if (buttonstate == HIGH) {
    int Value = qt_1.measure();
    Serial.println("CAP Mode");
    Serial.println(Value);


    i = map(Value, sensorMin, sensorMax, 0, 11);
    red = map(Value, sensorMin, sensorMax, 0, 255);
    int note = map(Value, sensorMin, sensorMax, 2489, 4978);

    int color = pixels.Color(red, 10, 10);
    pixels.fill(color, 0, i);
    delay(10);
    pixels.show();   // Send the updated pixel colors to the hardware.


    if (Value < sensorMin + 50)
    {
      beep(sound, 0, 50);
    }
    else {
      beep(sound, note, 50);
    }

  }


  else {
    int Value = analogRead(sense);
    Serial.println("RES Mode");
    Serial.println(Value);


    i = map(Value, sensorMin, sensorMax, 0, 11);
    blu = map(Value, sensorMin, sensorMax , 0, 255);
    int note = map(Value, sensorMin, sensorMax, 2489, 4978);

    int color = pixels.Color(10, 10, blu);
    pixels.fill(color, 0, i);
    delay(10);
    pixels.show();   // Send the updated pixel colors to the hardware.


    if (Value < sensorMin + 50)
    {
      beep(sound, 0, 50);
    }
    else {
      beep(sound, note, 50);
    }
  }

  delay (250);

}

void beep (unsigned char speakerPin, int frequencyInHertz, long timeInMilliseconds)
{ // http://web.media.mit.edu/~leah/LilyPad/07_sound_code.html
  int  x;
  long delayAmount = (long)(1000000 / frequencyInHertz);
  long loopTime = (long)((timeInMilliseconds * 1000) / (delayAmount * 2));
  for (x = 0; x < loopTime; x++) {
    digitalWrite(speakerPin, HIGH);
    delayMicroseconds(delayAmount);
    digitalWrite(speakerPin, LOW);
    delayMicroseconds(delayAmount);
  }



}

void theaterChase(uint32_t color, int wait) {
  for (int a = 0; a < 10; a++) { // Repeat 10 times...
    for (int b = 0; b < 3; b++) { //  'b' counts from 0 to 2...
      pixels.clear();         //   Set all pixels in RAM to 0 (off)
      // 'c' counts up from 'b' to end of strip in steps of 3...
      for (int c = b; c < pixels.numPixels(); c += 3) {
        pixels.setPixelColor(c, color); // Set pixel 'c' to value 'color'
      }
      pixels.show(); // Update strip with new contents
      delay(wait);  // Pause for a moment
    }
  }
}
